@@ -31,6 +31,7 @@ import logging
 from abc import ABC
 from contextlib import contextmanager, suppress
 from hashlib import sha256
+from typing import TYPE_CHECKING, Any
 
 from virtualenv.util.lock import ReentrantFileLock
 from virtualenv.util.path import safe_delete
@@ -39,6 +40,10 @@ from virtualenv.version import __version__
 
 from .base import AppData, ContentStore
 
+if TYPE_CHECKING:
+    from collections.abc import Generator
+    from pathlib import Path
+
 LOGGER = logging.getLogger(__name__)
 
 
@@ -48,7 +53,7 @@ class AppDataDiskFolder(AppData):
     transient = False
     can_update = True
 
-    def __init__(self, folder) -> None:
+    def __init__(self, folder: str) -> None:
         self.lock = ReentrantFileLock(folder)
 
     def __repr__(self) -> str:
@@ -57,22 +62,22 @@ class AppDataDiskFolder(AppData):
     def __str__(self) -> str:
         return str(self.lock.path)
 
-    def reset(self):
+    def reset(self) -> None:
         LOGGER.debug("reset app data folder %s", self.lock.path)
         safe_delete(self.lock.path)
 
-    def close(self):
+    def close(self) -> None:
         """Do nothing."""
 
     @contextmanager
-    def locked(self, path):
-        path_lock = self.lock / path
+    def locked(self, path: Path) -> Generator[None]:
+        path_lock = self.lock / path  # ty: ignore[unsupported-operator]
         with path_lock:
             yield path_lock.path
 
     @contextmanager
-    def extract(self, path, to_folder):
-        root = ReentrantFileLock(to_folder()) if to_folder is not None else self.lock / "unzip" / __version__
+    def extract(self, path: Path, to_folder: Path | None) -> Generator[Path]:
+        root = ReentrantFileLock(to_folder()) if to_folder is not None else self.lock / "unzip" / __version__  # ty: ignore[call-non-callable]
         with root.lock_for_key(path.name):
             dest = root.path / path.name
             if not dest.exists():
@@ -80,13 +85,13 @@ class AppDataDiskFolder(AppData):
             yield dest
 
     @property
-    def py_info_at(self):
-        return self.lock / "py_info" / "4"
+    def py_info_at(self) -> ReentrantFileLock:
+        return self.lock / "py_info" / "4"  # ty: ignore[invalid-return-type]
 
-    def py_info(self, path):
+    def py_info(self, path: Path) -> PyInfoStoreDisk:
         return PyInfoStoreDisk(self.py_info_at, path)
 
-    def py_info_clear(self):
+    def py_info_clear(self) -> None:
         """clear py info."""
         py_info_folder = self.py_info_at
         with py_info_folder:
@@ -96,33 +101,33 @@ class AppDataDiskFolder(AppData):
                         if filename.exists():
                             filename.unlink()
 
-    def embed_update_log(self, distribution, for_py_version):
-        return EmbedDistributionUpdateStoreDisk(self.lock / "wheel" / for_py_version / "embed" / "3", distribution)
+    def embed_update_log(self, distribution: str, for_py_version: str) -> EmbedDistributionUpdateStoreDisk:
+        return EmbedDistributionUpdateStoreDisk(self.lock / "wheel" / for_py_version / "embed" / "3", distribution)  # ty: ignore[invalid-argument-type]
 
     @property
-    def house(self):
+    def house(self) -> Path:
         path = self.lock.path / "wheel" / "house"
         path.mkdir(parents=True, exist_ok=True)
         return path
 
-    def wheel_image(self, for_py_version, name):
+    def wheel_image(self, for_py_version: str, name: str) -> Path:
         return self.lock.path / "wheel" / for_py_version / "image" / "1" / name
 
 
 class JSONStoreDisk(ContentStore, ABC):
-    def __init__(self, in_folder, key, msg_args) -> None:
+    def __init__(self, in_folder: ReentrantFileLock, key: str, msg_args: tuple[str, ...]) -> None:
         self.in_folder = in_folder
         self.key = key
         self.msg_args = (*msg_args, self.file)
 
     @property
-    def file(self):
+    def file(self) -> Path:
         return self.in_folder.path / f"{self.key}.json"
 
-    def exists(self):
+    def exists(self) -> bool:
         return self.file.exists()
 
-    def read(self):
+    def read(self) -> Any:  # noqa: ANN401
         data, bad_format = None, False
         try:
             data = json.loads(self.file.read_text(encoding="utf-8"))
@@ -138,16 +143,16 @@ class JSONStoreDisk(ContentStore, ABC):
                 self.remove()
         return None
 
-    def remove(self):
+    def remove(self) -> None:
         self.file.unlink()
         LOGGER.debug("removed %s %s at %s", *self.msg_args)
 
     @contextmanager
-    def locked(self):
+    def locked(self) -> Generator[None]:
         with self.in_folder.lock_for_key(self.key):
             yield
 
-    def write(self, content):
+    def write(self, content: Any) -> None:  # noqa: ANN401
         folder = self.file.parent
         folder.mkdir(parents=True, exist_ok=True)
         self.file.write_text(json.dumps(content, sort_keys=True, indent=2), encoding="utf-8")
@@ -155,13 +160,13 @@ class JSONStoreDisk(ContentStore, ABC):
 
 
 class PyInfoStoreDisk(JSONStoreDisk):
-    def __init__(self, in_folder, path) -> None:
+    def __init__(self, in_folder: ReentrantFileLock, path: Path) -> None:
         key = sha256(str(path).encode("utf-8")).hexdigest()
-        super().__init__(in_folder, key, ("python info of", path))
+        super().__init__(in_folder, key, ("python info of", path))  # ty: ignore[invalid-argument-type]
 
 
 class EmbedDistributionUpdateStoreDisk(JSONStoreDisk):
-    def __init__(self, in_folder, distribution) -> None:
+    def __init__(self, in_folder: ReentrantFileLock, distribution: str) -> None:
         super().__init__(
             in_folder,
             distribution,
