@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import logging
 from copy import copy
+from typing import TYPE_CHECKING
 
 from python_discovery import PythonInfo
 
@@ -15,22 +16,27 @@ from .builtin.cpython.common import is_mac_os_framework
 from .builtin.cpython.mac_os import CPython3macOsBrew
 from .builtin.pypy.pypy3 import Pypy3Windows
 
+if TYPE_CHECKING:
+    from typing import Any
+
+    from virtualenv.config.cli.parser import VirtualEnvOptions
+
 LOGGER = logging.getLogger(__name__)
 
 
 class Venv(ViaGlobalRefApi):
-    def __init__(self, options, interpreter) -> None:
+    def __init__(self, options: VirtualEnvOptions, interpreter: PythonInfo) -> None:
         self.describe = options.describe
         super().__init__(options, interpreter)
         current = PythonInfo.current()
         self.can_be_inline = interpreter is current and interpreter.executable == interpreter.system_executable
         self._context = None
 
-    def _args(self):
+    def _args(self) -> list[tuple[str, Any]]:
         return super()._args() + ([("describe", self.describe.__class__.__name__)] if self.describe else [])
 
     @classmethod
-    def can_create(cls, interpreter):
+    def can_create(cls, interpreter: PythonInfo) -> ViaGlobalRefMeta | None:
         if interpreter.has_venv:
             if CPython3macOsBrew.can_describe(interpreter):
                 return CPython3macOsBrew.setup_meta(interpreter)
@@ -42,26 +48,26 @@ class Venv(ViaGlobalRefApi):
             return meta
         return None
 
-    def create(self):
+    def create(self) -> None:
         if self.can_be_inline:
             self.create_inline()
         else:
             self.create_via_sub_process()
-        for lib in self.libs:
+        for lib in self.libs:  # ty: ignore[not-iterable]
             ensure_dir(lib)
         if self.describe is not None:
             self.describe.install_venv_shared_libs(self)
         super().create()
         self.executables_for_win_pypy_less_v37()
 
-    def executables_for_win_pypy_less_v37(self):
+    def executables_for_win_pypy_less_v37(self) -> None:
         """PyPy <= 3.6 (v7.3.3) for Windows contains only pypy3.exe and pypy3w.exe Venv does not handle non-existing exe sources, e.g. python.exe, so this patch does it."""
         creator = self.describe
         if isinstance(creator, Pypy3Windows) and creator.less_v37:
             for exe in creator.executables(self.interpreter):
                 exe.run(creator, self.symlinks)
 
-    def create_inline(self):
+    def create_inline(self) -> None:
         from venv import EnvBuilder  # noqa: PLC0415
 
         builder = EnvBuilder(
@@ -72,27 +78,27 @@ class Venv(ViaGlobalRefApi):
         )
         builder.create(str(self.dest))
 
-    def create_via_sub_process(self):
+    def create_via_sub_process(self) -> None:
         cmd = self.get_host_create_cmd()
         LOGGER.info("using host built-in venv to create via %s", " ".join(cmd))
         code, out, err = run_cmd(cmd)
         if code != 0:
             raise ProcessCallFailedError(code, out, err, cmd)
 
-    def get_host_create_cmd(self):
+    def get_host_create_cmd(self) -> list[str]:
         cmd = [self.interpreter.system_executable, "-m", "venv", "--without-pip"]
         if self.enable_system_site_package:
             cmd.append("--system-site-packages")
         cmd.extend(("--symlinks" if self.symlinks else "--copies", str(self.dest)))
-        return cmd
+        return cmd  # ty: ignore[invalid-return-type]
 
-    def set_pyenv_cfg(self):
+    def set_pyenv_cfg(self) -> None:
         # prefer venv options over ours, but keep our extra
         venv_content = copy(self.pyenv_cfg.refresh())
         super().set_pyenv_cfg()
         self.pyenv_cfg.update(venv_content)
 
-    def __getattribute__(self, item):
+    def __getattribute__(self, item: str) -> object:
         describe = object.__getattribute__(self, "describe")
         if describe is not None and hasattr(describe, item):
             element = getattr(describe, item)
