@@ -1,13 +1,19 @@
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 from .base import PluginLoader
 
+if TYPE_CHECKING:
+    from virtualenv.config.cli.parser import VirtualEnvConfigParser
+    from virtualenv.discovery.discover import Discover
+
 
 class Discovery(PluginLoader):
     """Discovery plugins."""
 
 
-def get_discover(parser, args):
+def get_discover(parser: VirtualEnvConfigParser, args: list[str] | None) -> Discover:
     discover_types = Discovery.entry_points_for("virtualenv.discovery")
     discovery_parser = parser.add_argument_group(
         title="discovery",
@@ -29,13 +35,22 @@ def get_discover(parser, args):
         help="interpreter discovery method",
     )
     options, _ = parser.parse_known_args(args)
-    discover_class = discover_types[options.discovery]
-    discover_class.add_parser_arguments(discovery_parser)
+    discovery = options.discovery
+    if discovery not in discover_types:
+        available = ", ".join(sorted(discover_types))
+        msg = (
+            f"discovery {discovery!r} is not available. "
+            f"Available discovery methods: {available}. "
+            f"Is the plugin installed?"
+        )
+        raise RuntimeError(msg)
+    discover_class = discover_types[discovery]
+    discover_class.add_parser_arguments(discovery_parser)  # ty: ignore[unresolved-attribute]
     options, _ = parser.parse_known_args(args, namespace=options)
     return discover_class(options)
 
 
-def _get_default_discovery(discover_types):
+def _get_default_discovery(discover_types: dict[str, type]) -> list[str]:
     return list(discover_types.keys())
 
 
