@@ -8,14 +8,19 @@ from abc import ABC, abstractmethod
 from contextlib import contextmanager, suppress
 from pathlib import Path
 from threading import Lock, RLock
+from typing import TYPE_CHECKING
 
 from filelock import FileLock, Timeout
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+    from types import TracebackType
+
 LOGGER = logging.getLogger(__name__)
 
 
 class _CountedFileLock(FileLock):
-    def __init__(self, lock_file) -> None:
+    def __init__(self, lock_file: str) -> None:
         parent = os.path.dirname(lock_file)
         with suppress(OSError):
             os.makedirs(parent, exist_ok=True)
@@ -24,7 +29,11 @@ class _CountedFileLock(FileLock):
         self.count = 0
         self.thread_safe = RLock()
 
-    def acquire(self, timeout=None, poll_interval=0.05):
+    def acquire(  # ty: ignore[invalid-method-override]
+        self,
+        timeout: float | None = None,
+        poll_interval: float = 0.05,
+    ) -> None:
         if not self.thread_safe.acquire(timeout=-1 if timeout is None else timeout):
             raise Timeout(self.lock_file)
         if self.count == 0:
@@ -35,7 +44,7 @@ class _CountedFileLock(FileLock):
                 raise
         self.count += 1
 
-    def release(self, force=False):  # noqa: FBT002
+    def release(self, force: bool = False) -> None:  # noqa: FBT002
         with self.thread_safe:
             if self.count > 0:
                 if self.count == 1:
@@ -51,41 +60,43 @@ _store_lock = Lock()
 
 
 class PathLockBase(ABC):
-    def __init__(self, folder) -> None:
+    def __init__(self, folder: str | Path) -> None:
         path = Path(folder)
         self.path = path.resolve() if path.exists() else path
 
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}({self.path})"
 
-    def __truediv__(self, other):
+    def __truediv__(self, other: str) -> PathLockBase:
         return type(self)(self.path / other)
 
     @abstractmethod
-    def __enter__(self):
+    def __enter__(self) -> None:
         raise NotImplementedError
 
     @abstractmethod
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(
+        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
+    ) -> None:
         raise NotImplementedError
 
     @abstractmethod
     @contextmanager
-    def lock_for_key(self, name, no_block=False):  # noqa: FBT002
+    def lock_for_key(self, name: str, no_block: bool = False) -> Iterator[None]:  # noqa: FBT002
         raise NotImplementedError
 
     @abstractmethod
     @contextmanager
-    def non_reentrant_lock_for_key(self, name):
+    def non_reentrant_lock_for_key(self, name: str) -> Iterator[None]:
         raise NotImplementedError
 
 
 class ReentrantFileLock(PathLockBase):
-    def __init__(self, folder) -> None:
+    def __init__(self, folder: str | Path) -> None:
         super().__init__(folder)
         self._lock = None
 
-    def _create_lock(self, name=""):
+    def _create_lock(self, name: str = "") -> _CountedFileLock:
         lock_file = str(self.path / f"{name}.lock")
         with _store_lock:
             if lock_file not in _lock_store:
@@ -93,7 +104,7 @@ class ReentrantFileLock(PathLockBase):
             return _lock_store[lock_file]
 
     @staticmethod
-    def _del_lock(lock):
+    def _del_lock(lock: _CountedFileLock | None) -> None:
         if lock is not None:
             with _store_lock, lock.thread_safe:
                 if lock.count == 0:
@@ -102,16 +113,18 @@ class ReentrantFileLock(PathLockBase):
     def __del__(self) -> None:
         self._del_lock(self._lock)
 
-    def __enter__(self):
+    def __enter__(self) -> None:
         self._lock = self._create_lock()
         self._lock_file(self._lock)
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        self._release(self._lock)
+    def __exit__(
+        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
+    ) -> None:
+        self._release(self._lock)  # ty: ignore[invalid-argument-type]
         self._del_lock(self._lock)
         self._lock = None
 
-    def _lock_file(self, lock, no_block=False):  # noqa: FBT002
+    def _lock_file(self, lock: _CountedFileLock, no_block: bool = False) -> None:  # noqa: FBT002
         # multiple processes might be trying to get a first lock... so we cannot check if this directory exist without
         # a lock, but that lock might then become expensive, and it's not clear where that lock should live.
         # Instead here we just ignore if we fail to create the directory.
@@ -128,11 +141,11 @@ class ReentrantFileLock(PathLockBase):
             lock.acquire()
 
     @staticmethod
-    def _release(lock):
+    def _release(lock: _CountedFileLock) -> None:
         lock.release()
 
     @contextmanager
-    def lock_for_key(self, name, no_block=False):  # noqa: FBT002
+    def lock_for_key(self, name: str, no_block: bool = False) -> Iterator[None]:  # noqa: FBT002
         lock = self._create_lock(name)
         try:
             try:
@@ -145,24 +158,26 @@ class ReentrantFileLock(PathLockBase):
             lock = None
 
     @contextmanager
-    def non_reentrant_lock_for_key(self, name):
+    def non_reentrant_lock_for_key(self, name: str) -> Iterator[None]:
         with _CountedFileLock(str(self.path / f"{name}.lock")):
             yield
 
 
 class NoOpFileLock(PathLockBase):
-    def __enter__(self):
+    def __enter__(self) -> None:
         raise NotImplementedError
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(
+        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
+    ) -> None:
         raise NotImplementedError
 
     @contextmanager
-    def lock_for_key(self, name, no_block=False):  # noqa: ARG002, FBT002
+    def lock_for_key(self, name: str, no_block: bool = False) -> Iterator[None]:  # noqa: ARG002, FBT002
         yield
 
     @contextmanager
-    def non_reentrant_lock_for_key(self, name):  # noqa: ARG002
+    def non_reentrant_lock_for_key(self, name: str) -> Iterator[None]:  # noqa: ARG002
         yield
 
 
